@@ -16,3 +16,10 @@ class TextEmbeddingSchema(Record):
     uuid = String(required=True)
     text = String()
     embedding = Array(Float())
+
+
+class TaskSchema(Record):
+    task_class = String(required=True)
+    task_id = String()
+    args = String()
+    kwargs = String()
